@@ -26,16 +26,13 @@ public:
 private Q_SLOTS:
     void askUserInput(const QString &serverError);
     void onPasswordRequestCompleted(const QString &password, bool userRejected);
-    void onDialogDestroyed();
     void onSettingsDialogFinished(int result);
 
 private:
-    void slotCancelClicked();
     void slotYesClicked();
     void slotNoClicked();
     QString requestManualAuth(bool *userRejected);
 
     ImapResourceBase *const m_resource;
-    QDialog *m_requestDialog = nullptr;
     QDialog *m_settingsDialog = nullptr;
 };
